@@ -1,4 +1,5 @@
 """Roborock exceptions."""
+
 from __future__ import annotations
 
 
@@ -60,3 +61,23 @@ class RoborockNoUserAgreement(RoborockException):
 
 class RoborockInvalidCredentials(RoborockException):
     """Class for Roborock credentials have expired or changed."""
+
+
+class RoborockTooFrequentCodeRequests(RoborockException):
+    """Class for Roborock too frequent code requests exceptions."""
+
+
+class RoborockMissingParameters(RoborockException):
+    """Class for Roborock missing parameters exceptions."""
+
+
+class RoborockTooManyRequest(RoborockException):
+    """Class for Roborock too many request exceptions."""
+
+
+class RoborockRateLimit(RoborockException):
+    """Class for our rate limits exceptions."""
+
+
+class RoborockNoResponseFromBaseURL(RoborockException):
+    """We could not find an url that had a record of the given account."""
